NECモバイルバックエンド基盤 Python SDK
======================================

NECモバイルバックエンド基盤の Python SDK です。
Python 2/3 両方に対応しています。

インストール
------------

    $ pip install necbaas

使用方法
--------

詳細なマニュアルは https://nec-baas.github.io/ にあります。

サンプルは sample/sample.py にあります。
